summaryrefslogtreecommitdiffstats
path: root/libkdegames/highscore/kexthighscore_item.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/highscore/kexthighscore_item.h')
-rw-r--r--libkdegames/highscore/kexthighscore_item.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libkdegames/highscore/kexthighscore_item.h b/libkdegames/highscore/kexthighscore_item.h
index 490908d7..d5faa380 100644
--- a/libkdegames/highscore/kexthighscore_item.h
+++ b/libkdegames/highscore/kexthighscore_item.h
@@ -79,10 +79,10 @@ class KDE_EXPORT Item
* Be sure to cast the value to the required type (for e.g. with uint).
* @param label the label corresponding to the item. If empty, the item
* is not shown.
* @param alignment the alignment of the item.
*/
Item(const TQVariant &def = TQVariant::Invalid,
- const TQString &label = TQString::null, int alignment = Qt::AlignRight);
+ const TQString &label = TQString(), int tqalignment = TQt::AlignRight);
virtual ~Item();
@@ -114,9 +114,9 @@ class KDE_EXPORT Item
TQString label() const { return _label; }
/**
- * @return the alignment.
+ * @return the tqalignment.
*/
- int alignment() const { return _alignment; }
+ int tqalignment() const { return _tqalignment; }
/**
* Set default value.
@@ -149,7 +149,7 @@ class KDE_EXPORT Item
private:
TQVariant _default;
TQString _label;
- int _alignment;
+ int _tqalignment;
Format _format;
Special _special;
@@ -294,7 +294,7 @@ class KDE_EXPORT MultiplayerScores
/**
* Show scores.
*/
- void show(TQWidget *parent);
+ void show(TQWidget *tqparent);
private:
TQValueVector<uint> _nbGames;
@@ -79,10 +79,10 @@ class KDE_EXPORT Item
* @param label the label corresponding to the item. If empty, the item
* is not shown.
- * @param alignment the alignment of the item.
+ * @param tqalignment the tqalignment of the item.
*/
Item(const TQVariant &def = TQVariant::Invalid,